# ConfigurationSelectModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project_ids** | **[str], none_type** | Collection of identifiers of projects from which configurations will be taken | [optional] 
**name** | **str, none_type** | Filter to search by name (case-insensitive, partial match) | [optional] 
**is_deleted** | **bool, none_type** | Is configurations deleted or existing | [optional] 
**global_ids** | **[int], none_type** | Collection of global (integer) identifiers to filter configurations | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


